 /*****************************************************************************
  Copyright (C) 2024 by Björn Lemke

  This code is derived from MariaDB/Connector written by Georg Richter

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not see <http://www.gnu.org/licenses>
  or write to the Free Software Foundation, Inc.,
  51 Franklin St., Fifth Floor, Boston, MA 02110, USA
 ****************************************************************************/

#include "Python.h"
#include "bytesobject.h"
#include "structmember.h"
#include "structseq.h"
#include <stdint.h>

/* cego c wrapper include */
#include <cego/cgwrap.h>

#include <time.h>
#include <docinfo.h>
#include <limits.h>

#define CHECK_TYPE(obj, type) \
(Py_TYPE((obj)) == type || PyType_IsSubtype(Py_TYPE((obj)), type))
#define CHECK_TYPE_NO_NONE(obj, type) \
(obj != Py_None && (Py_TYPE((obj)) == type || PyType_IsSubtype(Py_TYPE((obj)), type)))


/*
#ifndef MIN
#define MIN(a,b) (a) < (b) ? (a) : (b)
#endif

#ifndef MAX
#define MAX(a,b) (a) > (b) ? (a) : (b)
#endif
*/


/* Placeholder for missing documentation */
#define MISSING_DOC NULL

typedef struct {
    PyObject_HEAD
    CGDB* cgdb;
    PyObject *dsn; /* always null */
    uint8_t status;
    // char *server_info;
    // int open;
    // uint8_t is_closed;
    char closed;
} CegoConnection;


#define MAXBLOB 10
#define MAXOUTPARAM 10

typedef struct {
    PyObject_HEAD
    CegoConnection *connection;

    CGStmt *stmtHandle;
    CGFetch *fetchHandle;

    PyObject *statement;
    size_t statement_len;
    
    CGVal* fields;
    PyObject **values;


    int blobCount;
    PageIdType allocatedBlob[MAXBLOB];

    PyObject *outparam;
    
    int outParamCount;
    CGVal* allocatedOutParam[MAXOUTPARAM];
    
    int numparam;
    PyObject *data;
    
    PyObject *spname;

    int field_count;
    int row_count;
    unsigned long row_number;
    int closed;
} CegoCursor;


extern char *dsn_keys[];

/* Exceptions */
extern PyObject *Cego_InterfaceError;
extern PyObject *Cego_Error;
extern PyObject *Cego_DatabaseError;
extern PyObject *Cego_DataError;
extern PyObject *Cego_PoolError;
extern PyObject *Cego_OperationalError;
extern PyObject *Cego_IntegrityError;
extern PyObject *Cego_InternalError;
extern PyObject *Cego_ProgrammingError;
extern PyObject *Cego_NotSupportedError;
extern PyObject *Cego_Warning;

/* Object types */
extern PyTypeObject CegoPool_Type;
extern PyTypeObject CegoConnection_Type;
extern PyTypeObject CegoCursor_Type;

/* Function prototypes in cego_util */
int cegoutil_datetime_init(void);
void cegoutil_throw_exception(CGDB *cgdb,
			  PyObject *execption_type,
			  int8_t is_statement,
			  const char *message,
			  ...);

int cegoutil_bind_internal(CegoCursor *self, PyObject* obj, int pos, int inout);
char* cegoutil_object2string(PyObject *obj);
void cegoutil_field_fetch(CegoCursor *self, char *data, unsigned int column);
void  cegoutil_getprocinout(CegoCursor* self, char* procName, char* inoutinfo);
void cegoutil_free_blob(CegoCursor* self);
PyObject* cegoutil_cgval2object(int type, int len, char *data);
    
/* end of cego_util function prototypes */
