 /*****************************************************************************
  Copyright (C) 2024 by Björn Lemke

  This code is derived from MariaDB/Connector written by Georg Richter

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not see <http://www.gnu.org/licenses>
  or write to the Free Software Foundation, Inc.,
  51 Franklin St., Fifth Floor, Boston, MA 02110, USA
 ****************************************************************************/


#define __connect__doc__			\
    "connect(*args, **kwargs)\n"		\
    "--\n"					\
    "\n"								\
    "Establishes a connection to a database server and returns a connection\n" \
    "object.\n\n"							\
    "Connection parameters are provided as a set of keyword arguments:\n" \
    "----------------------\n"						\
    "host: string\n"							\
    "    The host name or IP address of the database server\n\n"	\
    "port: integer\n"							\
    "    port number of the database server. If not specified the default\n" \
    "    value of 3306 will be used.\n\n"				\
    "protocol: string\n"						\
    "    The communication protocol to the database server.\n"		\
    "    This depends on the server settings and is either 'xml', 'serial' or 'fastserial'.\n" \
    "username: string\n"						\
    "    The username used to authenticate with the database server\n\n" \
    "password: string\n"						\
    "    The password of the given user\n\n"				\
    "tableset: string\n"						\
    "    tableset name to use when connecting with the database\n"	\
    "    server\n\n"							\
    "autocommit: Boolean or None\n"					\
    "    Specifies the autocommit settings: None will use the server default," \
    "    True will enable autocommit, False will disable it (default).\n\n"


PyDoc_STRVAR(
    module_connect__doc__,
    __connect__doc__
    );

PyDoc_STRVAR(
    connection_connect__doc__,
    __connect__doc__
    );

PyDoc_STRVAR(
    connection__doc__,
    "The Connection class is used to open and manage a connection to a\n"
    "cego database server"
    );

PyDoc_STRVAR(
    connection_close__doc__,
    "close()\n"
    "--\n"
    "\n"
    "Close the connection now (rather than whenever .__del__() is called).\n\n"
    "The connection will be unusable from this point forward; an Error\n"
    "(or subclass) exception will be raised if any operation is attempted\n"
    "with the connection. The same applies to all cursor objects trying to\n"
    "use the connection.\n\n"
    "Note that closing a connection without committing the changes first\n"
    "will cause an implicit rollback to be performed."
    );

PyDoc_STRVAR(
    connection_ping__doc__, 
    "ping()\n"
    "--\n"
    "\n"
    "Checks if the connection to the database server is still available.\n\n"
    "If auto reconnect was set to true, an attempt will be made to reconnect\n"
    "to the database server in case the connection\n"
    "was lost\n\n"
    "If the connection is not available an InterfaceError will be raised."
    );

PyDoc_STRVAR(
    connection_warnings__doc__,
    "Returns the number of warnings from the last executed statement, or zero\n"
    "if there are no warnings."
    );

PyDoc_STRVAR(
    cursor_description__doc__,
    "This feature is not supported\n"
    );

PyDoc_STRVAR(
    cursor_warnings__doc__,
    "Returns the number of warnings from the last executed statement, or zero\n"
    "if there are no warnings.\n\n"
    );

PyDoc_STRVAR(
    cursor_closed__doc__,
    "Indicates if the cursor is closed and can't be reused"
    );

PyDoc_STRVAR(
    cursor_close__doc__,
    "close()\n"
    "--\n"
    "\n"
    "Closes the cursor. If the cursor has pending or unread results, .close()\n"
    "will cancel them so that further operations using the same connection\n"
    "can be executed.\n\n"
    "The cursor will be unusable from this point forward; an Error (or subclass)\n"
    "exception will be raised if any operation is attempted with the cursor."
    );

PyDoc_STRVAR(
    cursor_fetchone__doc__,
    "fetchone()\n"
    "--\n"
    "\n"
    "Fetches next row of a pending result set and returns a tuple.\n"
    );

PyDoc_STRVAR(
    cursor_field_count__doc__,
    "field_count()\n"
    "--\n"
    "\n"
    "Returns the number of fields (columns) of a result set."
    );

PyDoc_STRVAR(
    cursor_next__doc__,
    "next()\n"
    "--\n"
    "\n"
    "Return the next row from the currently executed SQL statement\n"
    "using the same semantics as .fetchone()."
    );

PyDoc_STRVAR(
    cursor_statement__doc__,
    "(read only)\n\n"
    "The last executed statement"
    );

PyDoc_STRVAR(
    cursor_rownumber__doc__,
    "(read only)\n\n"
    "Current row number in result set"
    );

PyDoc_STRVAR(
    cursor_paramcount__doc__,
    "(read)\n\n"
    "Returns the number of parameter markers present in the executed statement."
    );

PyDoc_STRVAR(
    exception_interface__doc__,
    "Exception raised for errors that are related to the database interface " \
    "rather than the database itself"
);

PyDoc_STRVAR(
    exception_warning__doc__,
    "Exception raised for important warnings like data truncations "\
    "while inserting, etc"
);

PyDoc_STRVAR(
    exception_database__doc__,
   "Exception raised for errors that are related to the database"
);

PyDoc_STRVAR(
    exception_data__doc__,
    "Exception raised for errors that are due to problems with the "\
    "processed data like division by zero, numeric value out of range, etc."
);

PyDoc_STRVAR(
    exception_pool__doc__,
    "Exception raised for errors related to ConnectionPool class."
);

PyDoc_STRVAR(
    exception_operational__doc__,
    "Exception raised for errors that are related to the database's "\
    "operation and not necessarily under the control of the programmer."
);

PyDoc_STRVAR(
    exception_integrity__doc__,
    "Exception raised when the relational integrity of the database "\
    "is affected, e.g. a foreign key check fails"
);

PyDoc_STRVAR(
    exception_internal__doc__,
    "Exception raised when the database encounters an internal error, "\
    "e.g. the cursor is not valid anymore";
);

PyDoc_STRVAR(
    exception_programming__doc__,
    "Exception raised for programming errors, e.g. table not found or "\
    "already exists, syntax error in the SQL statement"
);

PyDoc_STRVAR(
    exception_notsupported__doc__,
    "Exception raised in case a method or database API was used which is "\
    "not supported by the database"
);
