#!/usr/bin/env python

import os
import ast

from setuptools import setup, Extension
from configparser import ConfigParser

# read the contents of your README file
from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

define_macros = []

# read settings from site.cfg
c = ConfigParser()
c.read(['site.cfg'])
options = dict(c.items('cc_options'))

INCLUDEDIR = ast.literal_eval(c.get("cc_options", "includedir"))
LIBDIR = ast.literal_eval(c.get("cc_options", "libdir"))
CEGOLIB = ast.literal_eval(c.get("cc_options", "cegolib"))

PY_CEGO_AUTHORS = "Björn Lemke"
PY_CEGO_MAJOR_VERSION = 1
PY_CEGO_MINOR_VERSION = 0 
PY_CEGO_PATCH_VERSION = 0

PY_CEGO_PRE_RELEASE_SEGMENT = None
PY_CEGO_PRE_RELEASE_NR = 0
PY_CEGO_POST_RELEASE_SEGMENT = None
PY_CEGO_POST_RELEASE_NR = 0

PY_CEGO_VERSION = "%s.%s.%s" % (PY_CEGO_MAJOR_VERSION,
                                   PY_CEGO_MINOR_VERSION,
                                   PY_CEGO_PATCH_VERSION)

if PY_CEGO_POST_RELEASE_SEGMENT:
    PY_CEGO_VERSION += ".%s" % (PY_CEGO_POST_RELEASE_SEGMENT +
                                   PY_CEGO_POST_RELEASE_NR)

PY_CEGO_VERSION_INFO = (PY_CEGO_MAJOR_VERSION,
                           PY_CEGO_MINOR_VERSION,
                           PY_CEGO_PATCH_VERSION)

if PY_CEGO_PRE_RELEASE_SEGMENT:
    PY_CEGO_VERSION_INFO = PY_CEGO_VERSION_INFO + (
                                  PY_CEGO_PRE_RELEASE_SEGMENT,
                                  PY_CEGO_PRE_RELEASE_NR)

if PY_CEGO_POST_RELEASE_SEGMENT:
    PY_CEGO_VERSION_INFO = PY_CEGO_VERSION_INFO + (
                                  PY_CEGO_POST_RELEASE_SEGMENT,
                                  PY_CEGO_POST_RELEASE_NR)

define_macros.append(("PY_CEGO_MAJOR_VERSION", PY_CEGO_MAJOR_VERSION))
define_macros.append(("PY_CEGO_MINOR_VERSION", PY_CEGO_MINOR_VERSION))
define_macros.append(("PY_CEGO_PATCH_VERSION", PY_CEGO_PATCH_VERSION))
define_macros.append(("PY_CEGO_PRE_RELEASE_SEGMENT", "\"%s\"" %
                      PY_CEGO_PRE_RELEASE_SEGMENT))
define_macros.append(("PY_CEGO_PRE_RELEASE_NR", "\"%s\"" %
                      PY_CEGO_PRE_RELEASE_NR))
define_macros.append(("PY_CEGO_POST_RELEASE_SEGMENT", "\"%s\"" %
                      PY_CEGO_POST_RELEASE_SEGMENT))
define_macros.append(("PY_CEGO_POST_RELEASE_NR", "\"%s\"" %
                      PY_CEGO_POST_RELEASE_NR))


with open("cegodb/release_info.py", "w") as rel_info:
    rel_info.write("__author__ = '%s'\n__version__ = '%s'\n__version_info__"
                   " = %s\n" %
                   (PY_CEGO_AUTHORS, PY_CEGO_VERSION,
                    PY_CEGO_VERSION_INFO))

setup(name='cegodb',
      version=PY_CEGO_VERSION,
      python_requires='>=3.8',
      classifiers=[
          'Development Status :: 5 - Production/Stable',
          'Environment :: Console',
          'Environment :: MacOS X',
          'License :: OSI Approved :: GNU Lesser General Public License'
          ' v2 or later (LGPLv2+)',
          'Programming Language :: C',
          'Programming Language :: Python',
          'Programming Language :: Python :: 3.8',
          'Programming Language :: Python :: 3.9',
          'Programming Language :: Python :: 3.10',
          'Programming Language :: Python :: 3.11',
          'Programming Language :: Python :: 3.12',
          'Operating System :: MacOS',
          'Operating System :: POSIX',
          'Intended Audience :: End Users/Desktop',
          'Intended Audience :: Developers',
          'Intended Audience :: System Administrators',
          'Topic :: Database'
      ],
      description='Cego Python Driver',
      long_description=long_description,
      long_description_content_type='text/markdown',
      author=PY_CEGO_AUTHORS,
      license='LGPL 2.1',
      url='https://www.lemke-it.com/'
          'pythoncego',
      project_urls={
         "Documentation": "https://www.lemke-it.com/"
                          "pythoncego/",
         "Source Code": "https://www.lemke-it.com/"
                        "pythoncego",
      },
      install_requires=['packaging'],
      ext_modules=[Extension('cegodb._cegodb',
                             ['cegodb/cegodb.c',
                              'cegodb/cego_connection.c',
                              'cegodb/cego_cursor.c',
                              'cegodb/cego_util.c'],
                             define_macros=define_macros,
                             include_dirs=INCLUDEDIR,
                             library_dirs=LIBDIR,
                             libraries=CEGOLIB,
                             extra_compile_args='',
                             extra_link_args='',
                             extra_objects=''
                             )],
      py_modules=['cegodb.__init__',
                  'cegodb.connectionpool',
                  'cegodb.connection',
                  'cegodb.cursor',
                  'cegodb.release_info'])
