# Module Import
import cegodb
import sys
import dbcon
import datetime

# check integers
def check_int(cur):

    print(f"### Integer Check ###")
    cur.execute("drop if exists table t1;");
    cur.execute("create table t1 ( a int, b long, c smallint, d tinyint);");

    # Insert Integers
    cur.execute("insert into t1 values ( ?, ?, ?, ? );", ( 1, 2, 3, 4) )
    print(f"Rowcount = {cur.rowcount}")
    
    # Retrieve Integers
    cur.execute("select a, b, c, d from t1;")

    intval = []
    for (a, b, c, d ) in cur:
        intval.append(f"{a} {b} {c} {d}")
        
    # List Integers
    print("Results :")
    print("\n".join(intval))

# check datetime
def check_datetime(cur):

    print(f"### Datetime Check ###")
    cur.execute("drop if exists table t1;");
    cur.execute("create table t1 ( a datetime, b int);");

    tsnow = datetime.datetime(2024, 6, 24, 10, 30, 12)

    # print(f"TSnow = {tsnow}")
    # print(f"Formatted = {tsnow.strftime('%d.%m.%Y %H:%M:%S')}")
    
    # Insert Datetime
    cur.execute("insert into t1 values ( ?, ? );", ( tsnow.strftime('%d.%m.%Y %H:%M:%S'), 42  ) )
    print(f"Rowcount = {cur.rowcount}")
    
    # Retrieve Integers
    cur.execute("select a, b from t1;")

    dtval = []
    for [ a, b ] in cur:
        print(f"DT value = {a.strftime('%d.%m.%Y %H:%M:%S')}")
        dtval.append(f"{a} {b}")
        
    # List Datetime
    print("Results :")
    print("\n".join(dtval))

    

# check floats
def check_float(cur):

    print(f"### Float Check ###")
    cur.execute("drop if exists table t1;");
    cur.execute("create table t1 ( a float, b double);");

    # Insert Integers
    cur.execute("insert into t1 values ( ?, ? );", ( 1.45, 3.453667) )
    print(f"Rowcount = {cur.rowcount}")
    
    # Retrieve Integers
    cur.execute("select a, b from t1;")

    floatval = []
    for ( a, b ) in cur:
        floatval.append(f"{a} {b}")
        
    # List Integers
    print("Results :")
    print("\n".join(floatval))


    

print(f"Connecting to database ...")

myconn = dbcon.db_connect()

print(f"Creating cursor ...")
# Instantiate Cursor
cur = myconn.cursor()

check_int(cur)
check_float(cur)
check_datetime(cur)
        
print(f"Disconnecting database ...")
dbcon.db_disconnect(myconn)

